/* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
 * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
*/



#ifndef GADMIN_DHCPD_loadbalance_window_H
#   define GADMIN_DHCPD_loadbalance_window_H

extern struct w *widgets;

void show_loadbalance_window(struct w *widgets);

void cancel_loadbalance_button_clicked(struct w *widgets);

void apply_loadbalance_button_clicked(struct w *widgets);

void delete_loadbalance_button_clicked(struct w *widgets);


void rewrite_as_secondary_loadbalancer(struct w *widgets);    
void show_upload_menu(struct w *widgets);

#endif

